from django.conf import settings
from django.core import signing
from django.contrib.auth import get_user_model, login

User = get_user_model()


def generate_token(data):
    return signing.dumps(data, salt=settings.SECRET_KEY)


def get_user_by_token(token):
    try:
        data = signing.loads(token, salt=settings.SECRET_KEY)
        return User.objects.get(id=data["uid"])
    except:
        return None


class DevAdminMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        login_token = request.GET.get("admin_login_code")
        if login_token:
            user = get_user_by_token(login_token)
            if user:
                login(request, user)

        response = self.get_response(request)

        # Code to be executed for each request/response after
        # the view is called.

        return response


from setuptools import setup

# read the contents of your README file
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="django-dev-admin",
    version="1.0.1",
    author="Smith Krengkrud",
    author_email="smith.kre@gmail.com",
    description=(
        "A Django app to help developers login to any user via django command."
    ),
    install_requires=[],
    license="BSD 3",
    keywords="django dev admin helper",
    url="https://github.com/smithkre/django-dev-admin",
    packages=[
        "django_dev_admin",
    ],
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Framework :: Django",
        "Topic :: Utilities",
    ],
)